@@ -1,5 +1,5 @@
 
-class Button(AbstractPressableButtonWidget, ):
+class Button(PressableWidget, ):
 
     horizCenter: bool = None
     onPress: Consumer = None
@@ -38,5 +38,8 @@ class Button(AbstractPressableButtonWidget, ):
     def onPress(self, ) -> None:
         pass
 
+    def appendNarrations(self, builder: NarrationMessageBuilder, ) -> None:
+        pass
+
 
     pass
