@@ -1,4 +1,5 @@
 from .TextHelper import *
+from .CommandBuilder import *
 from .TextBuilder import *
 from .BaseLibrary import *
 
@@ -36,5 +37,8 @@ class FChat(BaseLibrary, ):
     def createTextBuilder(self, ) -> TextBuilder:
         pass
 
+    def createCommandBuilder(self, name: str, ) -> CommandBuilder:
+        pass
+
 
     pass
