@@ -1,5 +1,5 @@
 
-class Scrollbar(AbstractButtonWidget, ):
+class Scrollbar(ClickableWidget, ):
 
 
 
@@ -28,5 +28,8 @@ class Scrollbar(AbstractButtonWidget, ):
     def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float, ) -> None:
         pass
 
+    def appendNarrations(self, builder: NarrationMessageBuilder, ) -> None:
+        pass
+
 
     pass
